# Example Package

This is a simple example package. You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.

# pip 
```
py -m pip install --upgrade pip
py -m pip install --upgrade build
py -m pip install --upgrade twine
```

# build
```py -m build
```

# upload
```
py -m twine upload --repository pypi dist/*
```